==> jc-1.4.0.tar.gz: soot/jimple/parser/node/PParameterList.h <==
// public abstract class soot.jimple.parser.node.PParameterList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class fb94fdee60938d55 soot_jimple_parser_node_PParameterList

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PParameterList_H_
#define _JC_soot_jimple_parser_node_PParameterList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PParameterList$sub_refs	_jc_soot_jimple_parser_node_PParameterList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs	_jc_soot_jimple_parser_node_PParameterList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$refs	_jc_soot_jimple_parser_node_PParameterList$refs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$nonrefs	_jc_soot_jimple_parser_node_PParameterList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$object	_jc_soot_jimple_parser_node_PParameterList$object;

typedef const struct _jc_soot_jimple_parser_node_PParameterList$vmethods	_jc_soot_jimple_parser_node_PParameterList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PParameterList$vtable	_jc_soot_jimple_parser_node_PParameterList$vtable;
typedef const struct _jc_soot_jimple_parser_node_PParameterList$vtype	_jc_soot_jimple_parser_node_PParameterList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PParameterList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PParameterList$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PParameterList$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PParameterList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PParameterList$vmethods	soot_jimple_parser_node_PParameterList;
};

// Vtype
struct _jc_soot_jimple_parser_node_PParameterList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PParameterList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PParameterList$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PParameterList$refs {
    _jc_soot_jimple_parser_node_PParameterList$sub_refs	soot_jimple_parser_node_PParameterList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PParameterList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs	soot_jimple_parser_node_PParameterList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PParameterList$object {
	_jc_soot_jimple_parser_node_PParameterList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PParameterList$vtype	*vtype;
	_jc_soot_jimple_parser_node_PParameterList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PParameterList$vtype _jc_soot_jimple_parser_node_PParameterList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PParameterList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PParameterList$class_object;

#endif	/* _JC_soot_jimple_parser_node_PParameterList_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/PParameterList.h <==
// public abstract class soot.jimple.parser.node.PParameterList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class fb94fdee60938d55 soot_jimple_parser_node_PParameterList

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PParameterList_H_
#define _JC_soot_jimple_parser_node_PParameterList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PParameterList$sub_refs	_jc_soot_jimple_parser_node_PParameterList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs	_jc_soot_jimple_parser_node_PParameterList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$refs	_jc_soot_jimple_parser_node_PParameterList$refs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$nonrefs	_jc_soot_jimple_parser_node_PParameterList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PParameterList$object	_jc_soot_jimple_parser_node_PParameterList$object;

typedef const struct _jc_soot_jimple_parser_node_PParameterList$vmethods	_jc_soot_jimple_parser_node_PParameterList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PParameterList$vtable	_jc_soot_jimple_parser_node_PParameterList$vtable;
typedef const struct _jc_soot_jimple_parser_node_PParameterList$vtype	_jc_soot_jimple_parser_node_PParameterList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PParameterList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PParameterList$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PParameterList$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PParameterList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PParameterList$vmethods	soot_jimple_parser_node_PParameterList;
};

// Vtype
struct _jc_soot_jimple_parser_node_PParameterList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PParameterList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PParameterList$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PParameterList$refs {
    _jc_soot_jimple_parser_node_PParameterList$sub_refs	soot_jimple_parser_node_PParameterList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PParameterList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PParameterList$sub_nonrefs	soot_jimple_parser_node_PParameterList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PParameterList$object {
	_jc_soot_jimple_parser_node_PParameterList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PParameterList$vtype	*vtype;
	_jc_soot_jimple_parser_node_PParameterList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PParameterList$vtype _jc_soot_jimple_parser_node_PParameterList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PParameterList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PParameterList$class_object;

#endif	/* _JC_soot_jimple_parser_node_PParameterList_H_ */
